# fluffy-funicular
Experimental CSAF envelope and body profile validator.

## Status
Experimental.

## Installing
Recommended installation of current experimental package:
```
$ python -m pipx install csaf-lint
```



**Note**: The default branch is `default`.
